; Example code to accompany the presentation of:
;
;             Creative Solutions for Special Data Design Problems
;
;                    Craig L. Jones, Consultant/Developer
;
; This code is released to the public domain.

; NOTE: The following code was rendered here from memory and
; is not thoroughly tested!

;==========================================================================

; The following procedure returns TRUE if the second reading is a
; natural successor to the first reading and a "roll-over" has
; occurred.  FALSE is returned if a roll-over has not occurred.
; A result of "Error" indicates that either one reading or the
; other is negative, or that a typo has probably occurred since
; the second reading does not look like a natural successor to
; the first.

; NOTE: The following code was rendered here from memory and
; is untested in this form!

Proc HasRolledOver.l(Reading1.n,Reading2.n)
  If Reading1.n < 0 or Reading2.n < 0 Then
    Return "Error"
  EndIf
  If Reading1.n = 0 Then
    Digits1.n = 0
    Rank1.n = 0
  Else
    Digits1.n = Int(Log(Reading1.n))
    Rank1.n = Log(Reading1.n)-Digits1.n
  EndIf
  If Reading2.n = 0 Then
    Digits2.n = 0
    Rank2.n = 0
  Else
    Digits2.n = Int(Log(Reading2.n))
    Rank2.n = Log(Reading2.n)-Digits2.n
  EndIf
  Switch
  Case Digits1.n = Digits2.n:
    If Reading2.n >= Reading1.n then
      Return False
    Else
      If Rank2.n < 0.3 and Rank1.n > 0.9 Then
        Return True
      Else
        Return "Error"
      EndIf
    EndIf
  Case Digits1.n > Digits2.n:
    If Rank1.n > 0.9 Then
      Return True
    Else
      Return "Error"
    EndIf
  Case Digits1.n < Digits2.n:
    If Rank2.n < 0.3 and Rank1.n > 0.9 Then
      Return False
    Else
      Return "Error"
    EndIf
  EndSwitch
EndProc

ClearAll
Clear
? "94381.3   1925.0    should be true  -> ",HasRolledOver.l(94381.3,1925.0)
? "94381.3  98254.4    should be false -> ",HasRolledOver.l(94381.3,98254.4)
? "94381.3   9571.3    should be true  -> ",HasRolledOver.l(94381.3,9571.3)
? "94381.3  93571.3    should be error -> ",HasRolledOver.l(94381.3,93571.3)
Sleep 5000

; Note: as written, the third example should return true (and does), but
; you may wish add more restrictive testing so that such a case would return
; "Error".



;==========================================================================
; The following routine will check to see if a specified product contains
; a specified component (either direcly, or as a sub-component).  It
; returns true if so, and false otherwise.  This routine assumes that
; a table defining the components is already on the workspace, and that the
; table is keyed by [Product] and [Seq] (where [Seq] is a sequence number
; arbitrarily assigned to each component).  Also, the cursor must be placed
; in the [Product] field (column) before calling this routine.
;
;  [Product]    [Seq]   [Component]
; --------------------------------------------
;  Chasis         1      Base plate
;  Chasis         2      Power assembly
;  Dingus         1      3" crank
;  Dingus         2      4"x1/2" axle
;  Dingus         3      Pulley
;  Power assembly 1      Power cord
;  Power assembly 2      Fuse socket
;  Power assembly 3      3 Amp fuse
;  Widget         1      L-bracket
;  Widget         2      Chasis
;  Widget         3      10-4 screw, flat head


Proc IsComponent.l(Product.a,Component.a)
  Private Seq.s
  Locate Product.a
  While retval
    If [Component] = Component.a Then Return True EndIf
    Seq.s = [Seq]
    l = IsComponent.l([Component],Component.a)
    If l then Return True EndIf
    Locate Product.a,Seq.s
    Skip 1
    If EOT() Then Return False EndIf
    If [Product] <> Product.a Then Return False EndIf
    Locate Next Product.a
  EndWhile
  Return false
EndProc

ClearAll
Clear
View "Parts"
MoveTo [Product]
? "Widget   L-bracket  should be true  -> ",IsComponent.l("Widget","L-bracket")
? "Dingus   Power cord should be false -> ",IsComponent.l("Dingus","Power cord")
? "Widget   3 Amp fuse should be true  -> ",IsComponent.l("Widget","3 Amp fuse")
Sleep 5000

; Note: a nice added touch would be to check and see if the Products and
; Components passed are listed in the table at all.  If one or both are
; missing completely, then you might return "Error".
