; Enter2


;  ͻ
;   Enter2 Procedure                     
;  ͼ
;
;  This script contains the procedure for entering data into a multitable form
; for the following three tables:
;      EMPLOYEE - Master table
;      BENEFITS - One-to-One relationship
;      DEPNDNTS - One-to-Many relationship
;  ValChecks are augmented with PAL to insure the required fields are entered,
;  relational comparisons between fields are validated, and the defaults are
;  entered into a field if they are left blank.  These checks are made before
;  a user can move off the record.
;   The following assumptions may require changes based on user needs:
;         If the user does not move to the Benefits or Depndnts table, that
;        is taken to mean no data is to be entered.  Validation in applied to
;        these two tables only if the cursor is moved to the table.
;         It should also be noted that is this code example, a user must enter
;        data into a record once the data entry process has started unless
;        the entire session is cancelled.  An option can be added to this code
;        to allow the user to cancel the entry for the entire session OR the
;        current record.

PROC Enter2()
  CLEAR
  CURSOR OFF                                      ;  Place informational message
  MESSAGE "Loading form, Please wait"             ; on the screen while form is
  CANVAS OFF                                      ; loading
  IF ISEMPTY("Employee") THEN                     ;  If the table is empty, set
    empid = 1                                     ; the employee id counter to 1
  ELSE                                            ; otherwise calculate the max
    empid = CMAX("Employee","Employee ID") + 1    ; id in the table and add 1.
  ENDIF                                           ; This is used to set Employee
                                                  ; ID.
  MENU {Modify} {DataEntry} {Employee}
  {Image} {Pickform} {1}
  [Employee ID] = empid
  empid = empid + 1
  msg   = ""
  CANVAS ON                                       ;  Need to turn canvas on!
  WHILE True
    IF NOT ISBLANK(msg) THEN                      ;  If there is a message sound
      BEEP SLEEP 100 BEEP SLEEP 100 BEEP          ; the system bell
    ENDIF
    WAIT RECORD
      PROMPT "Enter New Employee Information    [F2]-Save/Exit    [Esc]-Cancel",
             "[F3]-Employee Data    [F4]-Benefits Data     " +
             "[F5]-Dependents Data"
      MESSAGE msg
      UNTIL "F2","F3","F4","F5","Esc","PgDn","PgUp","End","Home",  ; 15 - Ctrl O
            15,-24                                                 ;-24 - Alt O
    retkey = retval                               ;  Save the key pressed
    msg = ""                                      ;  Blank message variable
    tblname = TABLE()
    IF retkey <> "Esc" THEN                       ;  If any key except Esc is
      retprocval = ValidityChecks(tblname)        ; pressed, check if data is
                                                  ; valid.
      IF NOT retprocval THEN                      ;  If the proc returns False
        LOOP                                      ; the data did not pass the
      ENDIF                                       ; validation rule therefore do
    ELSE                                          ; not process the key pressed
      SHOWMENU
        "No"   : "Return to Data Entry",
        "Yes"  : "Cancel data entry session"
      TO canceloption
      IF canceloption = "Yes" THEN
        CLEAR
        MESSAGE "Data Entry cancelled"
        CANVAS OFF
        CANCELEDIT
        QUITLOOP
      ENDIF
      LOOP
    ENDIF
    SWITCH
      CASE retkey = "F2" :
           CLEAR
           MESSAGE "Saving data, Please wait"
           CANVAS OFF
           DO_IT!                                 ;  NOTE: need to check for
           QUITLOOP                               ; key violations in Depndnts
      CASE retkey = "F3" : MOVETO "Entry"         ;  Moveto Employee Table
      CASE retkey = "F4" : MOVETO "Entry1"        ;  Moveto Benefits Table
      CASE retkey = "F5" : MOVETO "Entry2"        ;  Moveto Depndnts Table
      CASE retkey = "PgDn" :
           SWITCH
             CASE tblname = "Entry" :
                  PgDn                             ;  Moveto next Employee rcd
                  IF ISBLANK([Employee ID]) THEN   ;  If this is a new record
                    [Employee ID] = empid          ; set the Employee ID
                    empid = empid + 1
                  ENDIF
             CASE tblname = "Entry1" :             ;  Only 1 record allowed for
                  BEEP LOOP                        ; Benefits table
             CASE tblname = "Entry2" :             ;  Moveto next record in
                  DOWN CtrlHome                    ; Depndnts table
           ENDSWITCH
      CASE retkey = "PgUp" :
           IF tblname = "Entry1" THEN              ;  Only 1 record allowed for
             BEEP                                  ; Benefits table
           ELSE                                    ;  For Employee and Depndnts
             SKIP -1                               ; move to the previous
           ENDIF                                   ; record
      OTHERWISE:
           IF retkey = 15 OR retkey = -24 THEN    ;  Beep is Alt or Ctrl O
             BEEP                                 ; is pressed
           ELSE
             KEYPRESS retkey
           ENDIF
    ENDSWITCH
  ENDWHILE
  CLEARALL
ENDPROC

WRITELIB "Intgrty" Enter2
RELEASE PROCS Enter2
