
;*************************************************************************
;SCRIPT       : PROCS.SC
;WRITTEN      : 6/89
;LAST MODIFIED: 2/90
;PDOX VER     : 2.0
;AUTHOR       : M. HACKETT

;DESC: THESE ARE THE LIBRARY ROUTINES FOR THE MEMO LOG PROGRAM MEMO.SC.
;SCRIPT CREATES LIBRARY "PROCS.LIB"
;*************************************************************************

CREATELIB "Procs"

;****************
PROC Mymsg(vtext)
;****************
;displays str in message window - does not clear until explicit clear

PRIVATE vint

vint = 80 - LEN(vtext)

STYLE ATTRIBUTE 79   ;Set color white on red
@ 22, vint ?? FORMAT("ar", vtext)
STYLE

ENDPROC
WRITELIB "Procs" Mymsg
RELEASE PROCS ALL

;*******************
PROC Pressany(vtext)
;*******************
;Display message to user then wait for keypress

PRIVATE v

CLEAR
STYLE REVERSE
@ 3, 0 ? FORMAT("w80,ac", vtext)
STYLE 
MESSAGE "Press any key to continue"
v = GETCHAR()

ENDPROC
WRITELIB "Procs" Pressany
RELEASE PROCS ALL

;****************
PROC Error(vtext)
;****************
;Called if error situation (LOCKRECORD)

PRIVATE v

CLEAR

STYLE REVERSE
@ 3, 0 ? FORMAT("w80,ac", vtext)
STYLE
MESSAGE "Press any key to continue"
v = GETCHAR()

ENDPROC
WRITELIB "Procs" Error
RELEASE PROCS ALL

;**************
PROC Edtlog()
;**************
;Processes editing of memo log - set STATUS behind scenes

;Code to edit memo record
CLEAR
STYLE INTENSE
@ 22, 34 ?? "[Esc] to Cancel"
STYLE
@ 10, 15 ?? "Please Enter MEMO NUMBER To Edit => "
ACCEPT "A20"
   PICTURE "*!"
   TO vmemo
IF retval = False THEN
   RETURN False
ENDIF

COEDIT "Memo"
MOVETO [MEMO NO]
LOCATE vmemo
IF retval = False THEN
   Pressany("Memo Number: " + vmemo + " Not Found")
   DO_IT!
   RETURN False
ENDIF

IMAGERIGHTS UPDATE  ;Do not allow to change key
FORMKEY
WAIT RECORD
   PROMPT "                        Edit Memo Log Information",
          "                          [F2] to Save and Quit"
   UNTIL "F2"
DO_IT!
IMAGERIGHTS
CLEARALL
RETURN True

ENDPROC
WRITELIB "Procs" Edtlog
RELEASE PROCS ALL

;************
PROC Genlog()
;************
;Code to generate memo number and insert record
;Sample memo number is R7001-FEB-1

COEDIT "Sequence"
WAIT TABLE
   PROMPT "                      Use Arrow Keys To Move To Entry",
          "                   [F2] to select, [Esc] for Previous Menu"
   UNTIL "F2", "Esc"
IF retval = "Esc" THEN
   DO_IT!  ;Get out of coedit mode
   CLEARALL
   RETURN False
ENDIF

Mymsg(" Generating Memo Number... ")
;Save record information
vorgno = [ORGNO]
vcurrent = [CURRENT]
LOCKRECORD
;Cannot lock record
IF retval = False THEN
   BEEP
   Error("Unable To Complete Transaction")
   DO_IT!
   CLEARALL
   LOOP
ENDIF

;Update next available [CURRENT] number in sequence tale
vnext = vcurrent + 1
[CURRENT] = vnext

UNLOCKRECORD
;Generates organization number, month and next sequence number
vmemo = vorgno + "-" + UPPER(MOY(TODAY())) + "-" + STRVAL(vnext)
DO_IT!
CLEARIMAGE

;Insert record in memo table with generated memo number
MENU {Modify} {CoEdit} {Memo} INS
[MEMO NO] = vmemo
[DATE] = TODAY()
DO_IT!
CLEARALL
CLEAR
Pressany("Your Memo Number is " + vmemo)

RETURN True

ENDPROC
WRITELIB "Procs" Genlog
RELEASE PROCS ALL

;**************
PROC Querylog()
;**************
;Allow to query memo number log

;Code to set up query
CLEARALL
SHOWMENU
   "OrgNo"         : "Query by Org No",
   "Subject"       : "Query by Subject",
   "Author/Signer" : "Query by Initiated By",
   "Return"        : "Return to Previous Menu"
TO vchoice
@ 24, 0 CLEAR EOS
IF vchoice = "Return" THEN
   RETURN False
ENDIF

STYLE INTENSE
@ 22, 34 ?? "[Esc] to Cancel"
STYLE
@ 10, 15 ?? "Please Enter " + vchoice + " to Match => "
ACCEPT "A20"
   PICTURE "*!"
   TO vstr
IF retval = False THEN
   CLEARALL
   RETURN False
ENDIF

CLEAR
CLEARALL
Mymsg(" Searching... ")

SWITCH
   CASE vchoice = "OrgNo" :
      MENU {Ask} {Memo}
         CHECK
         [MEMO NO] = "..~vstr.."

   CASE vchoice = "Subject" :
      MENU {Ask} {Memo}
         CHECK
         [SUBJECT] = "..~vstr.."

   CASE vchoice = "Author/Signer" :
      MENU {Ask} {Memo}
         CHECK
         [AUTHOR] = "..~vstr.."

ENDSWITCH

DO_IT!
IF NOT ISEMPTY("Answer") THEN
   COPYFORM "Memo" "F" "Answer" "F"
   CLEARALL
   VIEW "Answer"
   FORMKEY
   WAIT TABLE
      PROMPT "                  Use PgUp and PgDn to Move Between Records",
             "                               Press [F2] to End"
      MESSAGE STRVAL(NRECORDS("Answer")) + " Record(s) Found"
      UNTIL "F2"
ELSE
   Pressany("No Entries For: " + vchoice + " " + vstr)
   RETURN False
ENDIF

CLEAR
CLEARALL

RETURN True

ENDPROC
WRITELIB "Procs" Querylog
RELEASE PROCS ALL

;**************
PROC Printlog()
;**************
;Handles all printing of memo log report

PRIVATE vprint

CLEARALL
SHOWMENU
   "LPT1"   : "Print to local printer",
   "LPT2"   : "Print to network printer",
   "Return" : "Return to Previous Menu"
TO vprint
@ 24, 0 CLEAR EOS
IF vprint = "Esc" or vprint = "Return" THEN
   RETURN False
ENDIF

Mymsg(" Printing File... ")
COPYREPORT "Memo" "1" "Answer" "1"
;select printer
SETPRINTER vprint
OPEN PRINTER
REPORT "Memo" "1"

CLEAR

ENDPROC
WRITELIB "Procs" Printlog
RELEASE PROCS ALL


