; GOLDSTEIN,GOLUB, KESSLER & CO. 
;ͻ
;  SCRIPT NAME : REPORTS  - Automatic Report Generation               
;ͼ
;  by Elliot Reiter    DATE : 04/29/90   TIME : 09:00am 
;ͻ
;                                                                     
;        This script illustrates the use of "Script Data".  The       
;        data is stored in the table "Jobs".                          
;                                                                     
;        This script contains source code for Paradox3.  It was       
;        written by:                                                  
;                                                                     
;                   Elliot B. Reiter                                  
;                   Goldstein, Golub, Kessler and Company             
;                   1185 Avenue of the Americas                       
;                   New York, NY  10036-2602                          
;                   (212) 523-1325                                    
;                                                                     
;        This source code is intended for use at the International    
;        Paradox User's Conference.  Permission to use this source    
;        code is granted by the author.                               
;                                                                     
;ͼ

; Start of Reports Scripts

if (sysmode() <> "Main") then
 Message "The application can only be started from Paradox main mode"
 Sleep 3000
 return
endif

Echo Off
Release Vars All
Release Procs All
Clear
Reset

;ͻ
;                                                                     
;                       PROCEDURE DEFINITIONS                         
;                                                                     
;ͼ

                       ;ͻ
PROC DoDatesSetUp()    ;  Sets up the Last Day of each month in    
                       ;  order to determine End of Month steps.   
                       ;ͼ
TodaysDate = Today()
DayOfWeek = Dow(TodaysDate)

array LastDaysOfMonth[12]
LastDaysOfMonth[1]  = 31
If (DateVal("02/29/"+Strval(Year(TodaysDate)))) = "Error"
  then
     LastDaysOfMonth[2] = 28
else
     LastDaysOfMonth[2] = 29
Endif
LastDaysOfMonth[3]  = 31         LastDaysOfMonth[4]  = 30
LastDaysOfMonth[5]  = 31         LastDaysOfMonth[6]  = 30
LastDaysOfMonth[7]  = 31         LastDaysOfMonth[8]  = 31
LastDaysOfMonth[9]  = 30         LastDaysOfMonth[10] = 31
LastDaysOfMonth[11] = 30         LastDaysOfMonth[12] = 31

ENDPROC

                             ;ͻ
                             ;  For each job step, determines if it 
PROC DoReportDetermination() ;  is to be run based on "When to Run  
                             ;  Report" field.                      
                             ;  field.                              
                             ;ͼ
Switch
  Case [Jobs->When To Run Report] = "Daily":
     Return(True)

  Case [Jobs->When To Run Report] = "EOM-Weekend":
     If DayOfWeek = "Fri"  AND
        Day(TodaysDate) = LastDaysOfMonth[Month(TodaysDate)]
       then
          Return(True)
     Endif
     If DayOfWeek = "Fri" AND Day(TodaysDate) <= 06
       then
          Return(True)
     Endif
     Return(False)

  Case [Jobs->When To Run Report] = "EOM":
     If Day(TodaysDate) = LastDaysOfMonth[Month(TodaysDate)]
       then
          Return(True)
     Endif
     If DayOfWeek = "Fri"
       then
         If (Day(TodaysDate)+1 = LastDaysOfMonth[Month(TodaysDate)]) OR
            (Day(TodaysDate)+2 = LastDaysOfMonth[Month(TodaysDate)])
           then
             Return(True)
         Endif
     Endif
     Return(False)

  Case [Jobs->When To Run Report] = DayOfWeek:
     Return(True)
  otherwise:
     Return(False)

EndSwitch

ENDPROC

;ͻ
;                                                                     
;     HERE IS THE SCRIPT                                              
;                                                                     
;ͼ

@ 12,26 ?? "Report Generation In Progress"
@ 14,29 ?? "PLEASE DO NOT INTERRUPT"
DoDatesSetup()

View "Jobs"

SCAN

                             ;ͻ
   If [Bypass Report] = "Y"  ;  If set, we need not go any further.   
     then                    ;ͼ
        Loop
   Endif

                             ;ͻ
   DoReportDetermination()   ;  Does this step get run?               
   If NOT Retval             ;ͼ
     then
        If NOT [Run Report Anyway] = "Y"
          then
             Loop
        Endif
   Endif

                                           ;ͻ
   If NOT Isblank([Startup Script To Run]) ; Is there a Startup Script? 
     then                                  ;ͼ
        @ 24,1 ?? "Running " + [Startup Script To Run]
        Clear EOL
        Play [Startup Script To Run]
   Endif

                                           ;ͻ
   If NOT Isblank([Query Script To Run])   ; Is there a Query Script? 
     then                                  ;ͼ
        @ 24,1 ?? "Running " + [Query Script To Run]
        Clear EOL
        Play [Query Script To Run]
        Do_It!
        ClearImage   ; Clear Answer table from Workspace

        While NImages() > 1
           UpImage
           ClearImage    ; Clear Query script tables from Workspace
        EndWhile


             If NOT IsBlank([Jobs->Table Containing Report])
               then
                  @ 24,1 ?? "Preparing report " + [Jobs->Report Description]
                  Clear EOL
                  Copyreport [Jobs->Table Containing Report]
                             [Jobs->Which Report To Run]
                             "Answer" 1
                  If IsFile([Jobs->Destination File Name])
                    then
                       {Report} {Output} {Answer} {1} {File}
                       Execute "{" + [Jobs->Destination File Name] + "}"
                       {Replace}
                  Else
                       {Report} {Output} {Answer} {1} {File}
                       Execute "{" + [Jobs->Destination File Name] + "}"
                  Endif

             Endif

   Else

             If NOT IsBlank([Jobs->Table Containing Report])
               then
                @ 24,1 ?? "Preparing report " + [Jobs->Report Description]
                Clear EOL
                If IsFile([Jobs->Destination File Name])
                  then
                    {Report} {Output}
                    Execute "{" + [Jobs->Table Containing Report] +"}" +
                            "{" + [Jobs->Which Report To Run] + "}"
                    {File}
                    Execute "{" + [Jobs->Destination File Name] + "}"
                    {Replace}
                Else
                    {Report} {Output}
                    Execute "{" + [Jobs->Table Containing Report] +"}" +
                            "{" + [Jobs->Which Report To Run] + "}"
                    {File}
                    Execute "{" + [Jobs->Destination File Name] + "}"
                Endif
             Endif

   Endif

                                          ;ͻ
   If NOT Isblank([Exit Script To Run])   ; Is there an Exit Script? 
     then                                 ;ͼ
        @ 24,1 ?? "Running " + [Exit Script To Run]
        Clear EOL
        Play [Exit Script To Run]
   Endif

ENDSCAN

               ;ͻ
ClearImage     ;  Clear "Jobs" table.              
               ;ͼ

RETURN

;   E N D   O F   S C R I P T    
